@@ -19,6 +19,7 @@ import base64
 import datetime
 from enum import Enum
 from unittest import TestCase
+from uuid import UUID
 
 from ddt import ddt, named_data
 
@@ -42,6 +43,7 @@ from cyclonedx.model import (
     Property,
     XsUri,
 )
+from cyclonedx.model.bom_ref import BomRef
 from cyclonedx.model.contact import OrganizationalContact
 from cyclonedx.model.issue import IssueClassification, IssueType, IssueTypeSource
 from tests import reorder
@@ -545,6 +547,19 @@ class TestModelXsUri(TestCase):
         expected_uris = reorder(uris, expected_order)
         self.assertListEqual(sorted_uris, expected_uris)
 
+    def test_make_bom_link_without_bom_ref(self) -> None:
+        bom_link = XsUri.make_bom_link(UUID('e5a93409-fd7c-4ffa-bf7f-6dc1630b1b9d'), 2)
+        self.assertEqual(bom_link.uri, 'urn:cdx:e5a93409-fd7c-4ffa-bf7f-6dc1630b1b9d/2')
+
+    def test_make_bom_link_with_bom_ref(self) -> None:
+        bom_link = XsUri.make_bom_link(UUID('e5a93409-fd7c-4ffa-bf7f-6dc1630b1b9d'),
+                                       2, BomRef('componentA#sub-componentB%2'))
+        self.assertEqual(bom_link.uri, 'urn:cdx:e5a93409-fd7c-4ffa-bf7f-6dc1630b1b9d/2#componentA%23sub-componentB%252')
+
+    def test_is_bom_link(self) -> None:
+        self.assertTrue(XsUri('urn:cdx:e5a93409-fd7c-4ffa-bf7f-6dc1630b1b9d/2').is_bom_link())
+        self.assertFalse(XsUri('http://example.com/resource').is_bom_link())
+
 
 class TestModelProperty(TestCase):
 
